==> berty-2.395.0.tar.gz: berty-2.395.0/go/cmd/welcomebot/README.md <==
# Berty Welcome Bot

`Welcome Bot` is a Berty bot with the aim of onboarding people to discover the features of the app before having real friends also on the app.

## Usage

1. add the bot as contact

[embedmd]: # '../../../config/.tmp/qr-welcome-bot.txt txt'

```txt
█████████████████████████████████████████████████████
█████████████████████████████████████████████████████
████ ▄▄▄▄▄ ██▀▀▄  ▄█▄▀ ▄▄ ▀█▄▄  ▄▀ █▄▀█▀▄█ ▄▄▄▄▄ ████
████ █   █ █▄▀▄██▄▄█ ██▀▄  ▀▀▀▀██ ▄ ███ ▀█ █   █ ████
████ █▄▄▄█ ██▀▀  █  ▄ █  ▄▄▄ ▄  ▀▄ █▄█▄▄▄█ █▄▄▄█ ████
████▄▄▄▄▄▄▄█ ▀ ▀▄▀ ▀ ▀ ▀ █▄█ ▀▄█▄█ █ █ ▀ █▄▄▄▄▄▄▄████
████ ▄▄█ ▄▄ ▄█▄▄█ ██   ▄     ▄▄ ▄▄█▄ ▄█▀█▄▄▀▀▀ █▀████
████▄▄▀ ▄█▄▄ ▀▄▄   █▀▀▄████▄ ▄█▀ ▀▀█ ▀█▀  ▀▀ █▄ ▄████
████▄  ▀▄▀▄ ▄▀█ ▀▄ ▄█  █▄▀▄ ▀██▄ █▄█▄██▄█▄▄▄▄ █▄ ████
█████ █▄▀▄▄▄▄ ▀ ▄█▄▀▀▄▀█▄▄▄  ▀▄█ █▀▀ ▀ ▄ ███▀█▄█▄████
█████  ▄ ▄▄█▄ ▄▄██▄ ▄▄  ██▀▀ ██ ▄▄█▄▄▄▄███▄▄▄▄██▀████
████ █▀ ▀▄▄█▀▀██▀▀  ▄▄▄▄██▄█▄█▄    █▄██ █ ▀  ▀▄ ▄████
████  █  ▄▄▄  █▄██ ▄▄▄   ▄▄▄ ██▄  ▄  █▄▀ ▄▄▄  █▄ ████
████  ▀█ █▄█   ██ ▀ █ ▄  █▄█ ▀ █▀ ▀ ▀▄▄  █▄█  █▄▄████
████ ▀▄█▄▄▄ ▄██ ▄ ██ ▀▄  ▄▄▄▄▄█▄▄██ ▄▀▄▄▄▄ ▄▄ ▀█ ████
████▄  █ █▄█▀█▀ ▄▀ █▀  █▀▄█████▀▄█▄ ▄▀██   ▀ ▄▄ ▄████
████ ██▄▀ ▄▀█▄ ██▄▄▄▄ ▄█   ████ ▄▄▄ ▄█▄▀▀████ ▀█▀████
████▄    █▄▄▀ █ ▄█▄   ▀█▄  ▄█ ▀▄▄ ▄▄▀▀▄▀ ▀ ▀█▀█  ████
████▀█▀▀█▀▄▀█▄▄█ █▄ ▄ █▀▀  ▀▄██▄▄██  ▄██▄█ ████▀ ████
█████▀▀▀ █▄ ▄▄██▀▄  ▄▄ ▀ ▄▄▄█▀██▄▀▄ █▀██  ▄▀▀█▄  ████
████▄██▄▄█▄▄▀█▀ █  ███ ▀ ▄▄▄ ██  ▄█▄▄██▀ ▄▄▄ █ ██████
████ ▄▄▄▄▄ █ ▀█ █ ▀███▄█ █▄█ ▀▀█▀█  ▀▀▄█ █▄█  █  ████
████ █   █ █▄▀▀ ▄ ██ █▄█▄ ▄▄ ▄▄▀ █▄▄ ▄██ ▄   ██ █████
████ █▄▄▄█ █ ▄▀ ▄█ █▀▄▄ █▄▀██▀▀ ▄▀  ▀██  ██▄ █▄▀█████
████▄▄▄▄▄▄▄█▄█▄▄██▄█▄▄▄▄▄▄▄▄▄██▄▄██▄▄████▄█▄███▄▄████
█████████████████████████████████████████████████████
▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀
https://berty.tech/id#contact/oZBLF1QtpQqrKjikvbjJLVmDWSNJpevG5FiSZxqFr2Wc31nRqy8t9tDjhiikcJrCMxRDPBFmLNQ44xi5SJJTKckjvFFrjPu/name=Welcome-Bot
```

2. follow what the bot is saying

## Deployment

See [../../../tool/deployments/welcome-bot/](../../../tool/deployments/welcome-bot/)

==> berty-2.470.12.tar.gz: berty-2.470.12/go/cmd/welcomebot/README.md <==
# Berty Welcome Bot

`Welcome Bot` is a Berty bot with the aim of onboarding people to discover the features of the app before having real friends also on the app.

## Usage

1. add the bot as contact

[embedmd]: # '../../../config/.tmp/qr-welcome-bot.txt txt'

```txt
█████████████████████████████████████████████████████
█████████████████████████████████████████████████████
████ ▄▄▄▄▄ ██▀▀▄  ▄█▄▀ ▄▄ ▀█▄▄  ▄▀ █▄▀█▀▄█ ▄▄▄▄▄ ████
████ █   █ █▄▀▄██▄▄█ ██▀▄  ▀▀▀▀██ ▄ ███ ▀█ █   █ ████
████ █▄▄▄█ ██▀▀  █  ▄ █  ▄▄▄ ▄  ▀▄ █▄█▄▄▄█ █▄▄▄█ ████
████▄▄▄▄▄▄▄█ ▀ ▀▄▀ ▀ ▀ ▀ █▄█ ▀▄█▄█ █ █ ▀ █▄▄▄▄▄▄▄████
████ ▄▄█ ▄▄ ▄█▄▄█ ██   ▄     ▄▄ ▄▄█▄ ▄█▀█▄▄▀▀▀ █▀████
████▄▄▀ ▄█▄▄ ▀▄▄   █▀▀▄████▄ ▄█▀ ▀▀█ ▀█▀  ▀▀ █▄ ▄████
████▄  ▀▄▀▄ ▄▀█ ▀▄ ▄█  █▄▀▄ ▀██▄ █▄█▄██▄█▄▄▄▄ █▄ ████
█████ █▄▀▄▄▄▄ ▀ ▄█▄▀▀▄▀█▄▄▄  ▀▄█ █▀▀ ▀ ▄ ███▀█▄█▄████
█████  ▄ ▄▄█▄ ▄▄██▄ ▄▄  ██▀▀ ██ ▄▄█▄▄▄▄███▄▄▄▄██▀████
████ █▀ ▀▄▄█▀▀██▀▀  ▄▄▄▄██▄█▄█▄    █▄██ █ ▀  ▀▄ ▄████
████  █  ▄▄▄  █▄██ ▄▄▄   ▄▄▄ ██▄  ▄  █▄▀ ▄▄▄  █▄ ████
████  ▀█ █▄█   ██ ▀ █ ▄  █▄█ ▀ █▀ ▀ ▀▄▄  █▄█  █▄▄████
████ ▀▄█▄▄▄ ▄██ ▄ ██ ▀▄  ▄▄▄▄▄█▄▄██ ▄▀▄▄▄▄ ▄▄ ▀█ ████
████▄  █ █▄█▀█▀ ▄▀ █▀  █▀▄█████▀▄█▄ ▄▀██   ▀ ▄▄ ▄████
████ ██▄▀ ▄▀█▄ ██▄▄▄▄ ▄█   ████ ▄▄▄ ▄█▄▀▀████ ▀█▀████
████▄    █▄▄▀ █ ▄█▄   ▀█▄  ▄█ ▀▄▄ ▄▄▀▀▄▀ ▀ ▀█▀█  ████
████▀█▀▀█▀▄▀█▄▄█ █▄ ▄ █▀▀  ▀▄██▄▄██  ▄██▄█ ████▀ ████
█████▀▀▀ █▄ ▄▄██▀▄  ▄▄ ▀ ▄▄▄█▀██▄▀▄ █▀██  ▄▀▀█▄  ████
████▄██▄▄█▄▄▀█▀ █  ███ ▀ ▄▄▄ ██  ▄█▄▄██▀ ▄▄▄ █ ██████
████ ▄▄▄▄▄ █ ▀█ █ ▀███▄█ █▄█ ▀▀█▀█  ▀▀▄█ █▄█  █  ████
████ █   █ █▄▀▀ ▄ ██ █▄█▄ ▄▄ ▄▄▀ █▄▄ ▄██ ▄   ██ █████
████ █▄▄▄█ █ ▄▀ ▄█ █▀▄▄ █▄▀██▀▀ ▄▀  ▀██  ██▄ █▄▀█████
████▄▄▄▄▄▄▄█▄█▄▄██▄█▄▄▄▄▄▄▄▄▄██▄▄██▄▄████▄█▄███▄▄████
█████████████████████████████████████████████████████
▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀
https://berty.tech/id#contact/oZBLF1QtpQqrKjikvbjJLVmDWSNJpevG5FiSZxqFr2Wc31nRqy8t9tDjhiikcJrCMxRDPBFmLNQ44xi5SJJTKckjvFFrjPu/name=Welcome-Bot
```

2. follow what the bot is saying

## Deployment

See [../../../tool/deployments/welcomebot/](../../../tool/deployments/welcomebot/)
